@@ -1,14 +1,13 @@
 """
-Gateway __init__
+Discord Gateway framework
+
+Check github at ...
 """
 
 __title__ = 'DiscordGateway'
 __author__ = 'zYoshaa'
 __version__ = '1.0.1'
 
-import logging as log
-from typing import NamedTuple, Literal
-
 from .api import *
 from .constants import *
 from .discord_objects import *
@@ -16,6 +15,7 @@ from .discord_user import *
 from .gatewaybot import *
 from .gateway_handler import *
 from .gateway import *
+from .embed import *
+import logging as log
 
-
-log.basicConfig(encoding='utf-8', level=log.ERROR)
+log.basicConfig(encoding='utf-8', level=log.ERROR)
\ No newline at end of file
