@@ -32,3 +32,16 @@ class Intents(Enum):  # Discord intents
 class ChannelType(Enum):
     TextChannel: int = 0
     VoiceChannel: int = 2
+
+
+class Color(Enum):
+    Blue: int = 0x3498DB
+    Green: int = 0x2ECC71
+    Yellow: int = 0xFEE75C
+    Red: int = 0xE74C3C
+    Default: int = 0x8b8b8b
+    Orange: int = 0xE67E22
+    Gray: int = 0x898989
+    Gold: int = 0xeb8c26
+    Purple: int = 0xb024f1
+    Pink: int = 0xff2ebd
